@@ -2,10 +2,12 @@
 #define SG_CMDS_BASIC_H
 
 /*
- * Copyright (c) 2004-2018 Douglas Gilbert.
+ * Copyright (c) 2004-2020 Douglas Gilbert.
  * All rights reserved.
  * Use of this source code is governed by a BSD-style
  * license that can be found in the BSD_LICENSE file.
+ *
+ * SPDX-License-Identifier: BSD-2-Clause
  */
 
 /*
@@ -31,7 +33,13 @@ extern "C" {
  * sg_pt_base rather than an open file descriptor as their first argument.
  * That object is assumed to be constructed and have a device file descriptor
  * associated with it. clear_scsi_pt_obj() is called at the start of each
- * "_pt" function. Caller is responsible for lifetime of ptp. */
+ * "_pt" function. Caller is responsible for lifetime of ptp.
+ * If the sense buffer is accessed outside the "_pt" function then the caller
+ * must invoke set_scsi_pt_sense() _prior_ to the "_pt" function. Otherwise
+ * a sense buffer local to "_pt" function is used.
+ * Usually the cdb pointer will be NULL going into the "_pt" functions but
+ * could be given by the caller in which case it will used rather than a
+ * locally generated one. */
 
 struct sg_pt_base;
 
@@ -341,8 +349,8 @@ const char * sg_cmds_version();
  * output via 'o_sense_cat' pointer (if not NULL). Note that several sense
  * categories also have data in bytes received; -2 is still returned. */
 int sg_cmds_process_resp(struct sg_pt_base * ptvp, const char * leadin,
-                         int pt_res, int mx_di_len, const uint8_t * sense_b,
-                         bool noisy, int verbose, int * o_sense_cat);
+                         int pt_res, bool noisy, int verbose,
+                         int * o_sense_cat);
 
 /* NVMe devices use a different command set. This function will return true
  * if the device associated with 'pvtp' is a NVME device, else it will
